add VA_SURFACE_ATTRIB_MEM_TYPE_KERNEL_DRM_BO in va_drmcommon.h
authorZhao, Halley <halley.zhao@intel.com>
Sun, 16 Feb 2014 19:35:30 +0000 (03:35 +0800)
committerPhilippe Coval <philippe.coval@open.eurogiciel.org>
Wed, 12 Nov 2014 11:40:33 +0000 (12:40 +0100)
with small fixes

va/va.h
va/va_drmcommon.h

diff --git a/va/va.h b/va/va.h
index 01694a9..2f228de 100644 (file)
--- a/va/va.h
+++ b/va/va.h
@@ -2058,6 +2058,22 @@ VAStatus vaEndPicture (
     VAContextID context
 );
 
+VAStatus vaLockSurface(VADisplay dpy,
+    VASurfaceID surface,
+    unsigned int *fourcc, /* following are output argument */
+    unsigned int *luma_stride,
+    unsigned int *chroma_u_stride,
+    unsigned int *chroma_v_stride,
+    unsigned int *luma_offset,
+    unsigned int *chroma_u_offset,
+    unsigned int *chroma_v_offset,
+    unsigned int *buffer_name,
+    void **buffer
+);
+VAStatus vaUnlockSurface(VADisplay dpy,
+    VASurfaceID surface
+);
+
 /*
 
 Synchronization 
index 76820a3..7becdd3 100644 (file)
@@ -68,9 +68,11 @@ struct drm_state {
     int         auth_type;
 };
 
/** \brief Kernel DRM buffer memory type.  */
 #define VA_SURFACE_ATTRIB_MEM_TYPE_KERNEL_DRM          0x10000000
 /** \brief DRM PRIME memory type. */
 #define VA_SURFACE_ATTRIB_MEM_TYPE_DRM_PRIME           0x20000000
+/** \brief DRM buffer object memory type. the handle is per-process buffer object*/
+#define VA_SURFACE_ATTRIB_MEM_TYPE_KERNEL_DRM_BO       0x40000000
 
 #endif /* VA_DRM_COMMON_H */
@@ -68,9 +68,11 @@ struct drm_state {
 };
 
-/** \brief Kernel DRM buffer memory type.  */
+/** \brief Kernel DRM buffer memory type.  the handle is global buffer name(across processes)*/
 #define VA_SURFACE_ATTRIB_MEM_TYPE_KERNEL_DRM          0x10000000
 /** \brief DRM PRIME memory type. */